==> airyblue-6.x-1.0.tar.gz: airyblue/page.tpl.php <==
<?php
// $Id: page.tpl.php,v 1.1 2009/06/30 06:00:53 geerlingguy Exp $

/**
 * @file
 * Theme implementation to display a single Drupal page.
 *
 * Available variables:
 *
 * General utility variables:
 * - $base_path: The base URL path of the Drupal installation. At the very
 *   least, this will always default to /.
 * - $css: An array of CSS files for the current page.
 * - $directory: The directory the template is located in, e.g. modules/system
 *   or themes/garland.
 * - $body_classes_array: Array of the body classes. It is flattened
 *   into a string within the variable $classes.
 * - $is_front: TRUE if the current page is the front page. Used to toggle the mission statement.
 * - $logged_in: TRUE if the user is registered and signed in.
 * - $is_admin: TRUE if the user has permission to access administration pages.
 *
 * Page metadata:
 * - $language: (object) The language the site is being displayed in.
 *   $language->language contains its textual representation.
 *   $language->dir contains the language direction. It will either be 'ltr' or 'rtl'.
 * - $head_title: A modified version of the page title, for use in the TITLE tag.
 * - $head: Markup for the HEAD section (including meta tags, keyword tags, and
 *   so on).
 * - $styles: Style tags necessary to import all CSS files for the page.
 * - $scripts: Script tags necessary to load the JavaScript files and settings
 *   for the page.
 * - $body_classes: String of classes that can be used to style contextually through
 *   CSS. It should be placed within the <body> tag. When selecting through CSS
 *   it's recommended that you use the body tag, e.g., "body.front". It can be
 *   manipulated through the variable $classes_array from preprocess functions.
 *   The default values can be one or more of the following:
 *   - front: Page is the home page.
 *   - not-front: Page is not the home page.
 *   - logged-in: The current viewer is logged in.
 *   - not-logged-in: The current viewer is not logged in.
 *   - node-type-[node type]: When viewing a single node, the type of that node.
 *     For example, if the node is a "Blog entry" it would result in "node-type-blog".
 *     Note that the machine name will often be in a short form of the human readable label.
 *   The following only apply with the default 'first sidebar' and 'second sidebar' block regions:
 *     - two-sidebars: When both sidebars have content.
 *     - no-sidebars: When no sidebar content exists.
 *     - one-sidebar and sidebar-first or sidebar-second: A combination of
 *       the two classes when only one of the two sidebars have content.
 *
 * Site identity:
 * - $front_page: The URL of the front page. Use this instead of $base_path,
 *   when linking to the front page. This includes the language domain or prefix.
 * - $logo: The path to the logo image, as defined in theme configuration.
 * - $site_name: The name of the site, empty when display has been disabled
 *   in theme settings.
 * - $site_slogan: The slogan of the site, empty when display has been disabled
 *   in theme settings.
 * - $mission: The text of the site mission, empty when display has been disabled
 *   in theme settings.
 *
 * Navigation:
 * - $search_box: HTML to display the search box, empty if search has been disabled.
 * - $primary_links (array): An array containing the Primary menu links for the
 *   site, if they have been configured.
 * - $secondary_links (array): An array containing the Secondary menu links for
 *   the site, if they have been configured.
 * - $breadcrumb: The breadcrumb trail for the current page.
 *
 * Page content (in order of occurrence in the default page.tpl.php):
 * - $title: The page title, for use in the actual HTML content.
 * - $messages: HTML for status and error messages. Should be displayed prominently.
 * - $tabs: Tabs linking to any sub-pages beneath the current page (e.g., the view
 *   and edit tabs when displaying a node).
 * - $help: Dynamic help text, mostly for admin pages.
 * - $content: The main content of the current Drupal page.
 * - $feed_icons: A string of all feed icons for the current page.
 * - $left: The HTML for the first sidebar.
 * - $right: The HTML for the second sidebar.
 *
 * Footer/closing data:
 * - $footer_message: The footer message as defined in the admin settings.
 * - $footer : The footer region.
 * - $closure: Final closing markup from any modules that have altered the page.
 *   This variable should always be output last, after all other dynamic content.
 *
 * @see template_preprocess()
 * @see template_preprocess_page()
 */
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language; ?>" lang="<?php print $language->language; ?>" dir="<?php print $language->dir; ?>">

<head>
  <title><?php print $head_title; ?></title>
  <?php print $head; ?>
  <?php print $styles; ?>
  <?php print $scripts; ?>
</head>
<body class="<?php print $body_classes; ?>">
  <div id="body-wrapper">
    <div id="page"><div id="page-inner">

      <?php if ($primary_links || $secondary_links || $navbar): ?>
        <div id="skip-to-nav"><a href="#navigation"><?php print t('Skip to Navigation'); ?></a></div>
      <?php endif; ?>

      <div id="header"><div id="header-inner" class="clearfix">

        <?php if ($logo || $site_name || $site_slogan): ?>
          <div id="logo-title">

            <?php if ($logo): ?>
              <div id="logo"><a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home"><img src="<?php print $logo; ?>" alt="<?php print t('Home'); ?>" id="logo-image" /></a></div>
            <?php endif; ?>

            <?php if ($site_name): ?>
              <?php if ($title): ?>
                <div id="site-name">
                  <a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home">
                  <?php print $site_name; ?>
                  </a>
                </div>
              <?php else: /* Use h1 when the content title is empty */ ?>
                <h1 id="site-name">
                  <a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home">
                  <?php print $site_name; ?>
                  </a>
                </h1>
              <?php endif; ?>
            <?php endif; ?>

            <?php if ($site_slogan): ?>
              <div id="site-slogan"><?php print $site_slogan; ?></div>
            <?php endif; ?>

          </div> <!-- /#logo-title -->
        <?php endif; ?>

        <?php if ($search_box): ?>
          <div id="search-box"><?php print $search_box; ?></div>
        <?php endif; ?>

      </div></div> <!-- /#header-inner, /#header -->

      <div id="main"><div id="main-inner" class="clearfix<?php if ($primary_links || $secondary_links || $navbar) { print ' with-navbar'; } ?>">

        <div id="content"><div id="content-inner">

          <?php if ($mission): ?>
            <div id="mission"><?php print $mission; ?></div>
          <?php endif; ?>

          <?php if ($content_top): ?>
            <div id="content-top" class="region region-content_top">
              <?php print $content_top; ?>
            </div> <!-- /#content-top -->
          <?php endif; ?>

          <?php if ($breadcrumb || $title || $tabs || $help || $messages): ?>
            <div id="content-header">
              <?php print $breadcrumb; ?>
              <?php if ($title): ?>
                <h1 class="title"><?php print $title; ?></h1>
              <?php endif; ?>
              <?php print $messages; ?>
              <?php if ($tabs): ?>
                <div class="tabs"><?php print $tabs; ?></div>
              <?php endif; ?>
              <?php print $help; ?>
            </div> <!-- /#content-header -->
          <?php endif; ?>

          <div id="content-area">
            <?php print $content; ?>
          </div>

          <?php if ($feed_icons): ?>
            <div class="feed-icons"><?php print $feed_icons; ?></div>
          <?php endif; ?>

          <?php if ($content_bottom): ?>
            <div id="content-bottom" class="region region-content_bottom">
              <?php print $content_bottom; ?>
            </div> <!-- /#content-bottom -->
          <?php endif; ?>

        </div></div> <!-- /#content-inner, /#content -->

        <?php if ($primary_links || $secondary_links || $navbar): ?>
          <div id="navbar"><div id="navbar-inner" class="clearfix region region-navbar">

            <a name="navigation" id="navigation"></a>

            <?php if ($primary_links): ?>
              <div id="primary">
                <?php print theme('links', $primary_links); ?>
              </div> <!-- /#primary -->
            <?php endif; ?>

            <?php if ($secondary_links): ?>
              <div id="secondary">
                <?php print theme('links', $secondary_links); ?>
              </div> <!-- /#secondary -->
            <?php endif; ?>

            <?php print $navbar; ?>

          </div></div> <!-- /#navbar-inner, /#navbar -->
        <?php endif; ?>

        <?php if ($left): ?>
          <div id="sidebar-first"><div id="sidebar-first-inner" class="region region-sidebar-first">
            <?php print $left; ?>
          </div></div> <!-- /#sidebar-first-inner, /#sidebar-first -->
        <?php endif; ?>

        <?php if ($right): ?>
          <div id="sidebar-second"><div id="sidebar-second-inner" class="region region-sidebar-second">
            <?php print $right; ?>
          </div></div> <!-- /#sidebar-second-inner, /#sidebar-second -->
        <?php endif; ?>

      </div></div> <!-- /#main-inner, /#main -->

      <?php if ($footer || $footer_message): ?>
        <div id="footer"><div id="footer-inner" class="region region-footer">

          <?php if ($footer_message): ?>
            <div id="footer-message"><?php print $footer_message; ?></div>
          <?php endif; ?>

          <?php print $footer; ?>

        </div></div> <!-- /#footer-inner, /#footer -->
      <?php endif; ?>

    </div></div> <!-- /#page-inner, /#page -->
  </div> <!-- /#body-wrapper -->

  <?php if ($closure_region): ?>
    <div id="closure-blocks" class="region region-closure"><?php print $closure_region; ?></div>
  <?php endif; ?>

  <?php print $closure; ?>

</body>
</html>

==> airyblue-6.x-1.2.tar.gz: airyblue/page.tpl.php <==
<?php
// $Id: page.tpl.php,v 1.2 2009/08/24 06:41:20 geerlingguy Exp $

/**
 * @file
 * Theme implementation to display a single Drupal page.
 *
 * Available variables:
 *
 * General utility variables:
 * - $base_path: The base URL path of the Drupal installation. At the very
 *   least, this will always default to /.
 * - $css: An array of CSS files for the current page.
 * - $directory: The directory the template is located in, e.g. modules/system
 *   or themes/garland.
 * - $body_classes_array: Array of the body classes. It is flattened
 *   into a string within the variable $classes.
 * - $is_front: TRUE if the current page is the front page. Used to toggle the mission statement.
 * - $logged_in: TRUE if the user is registered and signed in.
 * - $is_admin: TRUE if the user has permission to access administration pages.
 *
 * Page metadata:
 * - $language: (object) The language the site is being displayed in.
 *   $language->language contains its textual representation.
 *   $language->dir contains the language direction. It will either be 'ltr' or 'rtl'.
 * - $head_title: A modified version of the page title, for use in the TITLE tag.
 * - $head: Markup for the HEAD section (including meta tags, keyword tags, and
 *   so on).
 * - $styles: Style tags necessary to import all CSS files for the page.
 * - $scripts: Script tags necessary to load the JavaScript files and settings
 *   for the page.
 * - $body_classes: String of classes that can be used to style contextually through
 *   CSS. It should be placed within the <body> tag. When selecting through CSS
 *   it's recommended that you use the body tag, e.g., "body.front". It can be
 *   manipulated through the variable $classes_array from preprocess functions.
 *   The default values can be one or more of the following:
 *   - front: Page is the home page.
 *   - not-front: Page is not the home page.
 *   - logged-in: The current viewer is logged in.
 *   - not-logged-in: The current viewer is not logged in.
 *   - node-type-[node type]: When viewing a single node, the type of that node.
 *     For example, if the node is a "Blog entry" it would result in "node-type-blog".
 *     Note that the machine name will often be in a short form of the human readable label.
 *   The following only apply with the default 'first sidebar' and 'second sidebar' block regions:
 *     - two-sidebars: When both sidebars have content.
 *     - no-sidebars: When no sidebar content exists.
 *     - one-sidebar and sidebar-first or sidebar-second: A combination of
 *       the two classes when only one of the two sidebars have content.
 *
 * Site identity:
 * - $front_page: The URL of the front page. Use this instead of $base_path,
 *   when linking to the front page. This includes the language domain or prefix.
 * - $logo: The path to the logo image, as defined in theme configuration.
 * - $site_name: The name of the site, empty when display has been disabled
 *   in theme settings.
 * - $site_slogan: The slogan of the site, empty when display has been disabled
 *   in theme settings.
 * - $mission: The text of the site mission, empty when display has been disabled
 *   in theme settings.
 *
 * Navigation:
 * - $search_box: HTML to display the search box, empty if search has been disabled.
 * - $primary_links (array): An array containing the Primary menu links for the
 *   site, if they have been configured.
 * - $secondary_links (array): An array containing the Secondary menu links for
 *   the site, if they have been configured.
 * - $breadcrumb: The breadcrumb trail for the current page.
 *
 * Page content (in order of occurrence in the default page.tpl.php):
 * - $title: The page title, for use in the actual HTML content.
 * - $messages: HTML for status and error messages. Should be displayed prominently.
 * - $tabs: Tabs linking to any sub-pages beneath the current page (e.g., the view
 *   and edit tabs when displaying a node).
 * - $help: Dynamic help text, mostly for admin pages.
 * - $content: The main content of the current Drupal page.
 * - $feed_icons: A string of all feed icons for the current page.
 * - $left: The HTML for the first sidebar.
 * - $right: The HTML for the second sidebar.
 *
 * Footer/closing data:
 * - $footer_message: The footer message as defined in the admin settings.
 * - $footer : The footer region.
 * - $closure: Final closing markup from any modules that have altered the page.
 *   This variable should always be output last, after all other dynamic content.
 *
 * @see template_preprocess()
 * @see template_preprocess_page()
 */
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language; ?>" lang="<?php print $language->language; ?>" dir="<?php print $language->dir; ?>">

<head>
  <title><?php print $head_title; ?></title>
  <?php print $head; ?>
  <?php print $styles; ?>
  <?php print $scripts; ?>
</head>
<body class="<?php print $body_classes; ?>">
  <div id="body-wrapper">
    <div id="page"><div id="page-inner">

      <?php if ($primary_links || $secondary_links || $navbar): ?>
        <div id="skip-to-nav"><a href="#navigation"><?php print t('Skip to Navigation'); ?></a></div>
      <?php endif; ?>

      <div id="header"><div id="header-inner" class="clearfix">

        <?php if ($logo || $site_name || $site_slogan): ?>
          <div id="logo-title">

            <?php if ($logo): ?>
              <div id="logo"><a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home"><img src="<?php print $logo; ?>" alt="<?php print t('Home'); ?>" id="logo-image" /></a></div>
            <?php endif; ?>

            <?php if ($site_name): ?>
              <?php if ($title): ?>
                <div id="site-name">
                  <a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home">
                  <?php print $site_name; ?>
                  </a>
                </div>
              <?php else: /* Use h1 when the content title is empty */ ?>
                <h1 id="site-name">
                  <a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home">
                  <?php print $site_name; ?>
                  </a>
                </h1>
              <?php endif; ?>
            <?php endif; ?>

            <?php if ($site_slogan): ?>
              <div id="site-slogan"><?php print $site_slogan; ?></div>
            <?php endif; ?>

          </div> <!-- /#logo-title -->
        <?php endif; ?>

        <?php if ($search_box): ?>
          <div id="search-box"><?php print $search_box; ?></div>
        <?php endif; ?>

      </div></div> <!-- /#header-inner, /#header -->

      <div id="main"><div id="main-inner" class="clear-box<?php if ($primary_links || $secondary_links || $navbar) { print ' with-navbar'; } ?>">

        <div id="content"><div id="content-inner">

          <?php if ($mission): ?>
            <div id="mission"><?php print $mission; ?></div>
          <?php endif; ?>

          <?php if ($content_top): ?>
            <div id="content-top" class="region region-content_top">
              <?php print $content_top; ?>
            </div> <!-- /#content-top -->
          <?php endif; ?>

          <?php if ($breadcrumb || $title || $tabs || $help || $messages): ?>
            <div id="content-header">
              <?php print $breadcrumb; ?>
              <?php if ($title): ?>
                <h1 class="title"><?php print $title; ?></h1>
              <?php endif; ?>
              <?php print $messages; ?>
              <?php if ($tabs): ?>
                <div class="tabs"><?php print $tabs; ?></div>
              <?php endif; ?>
              <?php print $help; ?>
            </div> <!-- /#content-header -->
          <?php endif; ?>

          <div id="content-area">
            <?php print $content; ?>
          </div>

          <?php if ($feed_icons): ?>
            <div class="feed-icons"><?php print $feed_icons; ?></div>
          <?php endif; ?>

          <?php if ($content_bottom): ?>
            <div id="content-bottom" class="region region-content_bottom">
              <?php print $content_bottom; ?>
            </div> <!-- /#content-bottom -->
          <?php endif; ?>

        </div></div> <!-- /#content-inner, /#content -->

        <?php if ($primary_links || $secondary_links || $navbar): ?>
          <div id="navbar"><div id="navbar-inner" class="clearfix region region-navbar">

            <a name="navigation" id="navigation"></a>

            <?php if ($primary_links): ?>
              <div id="primary">
                <?php print theme('links', $primary_links); ?>
              </div> <!-- /#primary -->
            <?php endif; ?>

            <?php if ($secondary_links): ?>
              <div id="secondary">
                <?php print theme('links', $secondary_links); ?>
              </div> <!-- /#secondary -->
            <?php endif; ?>

            <?php print $navbar; ?>

          </div></div> <!-- /#navbar-inner, /#navbar -->
        <?php endif; ?>

        <?php if ($left): ?>
          <div id="sidebar-first"><div id="sidebar-first-inner" class="region region-sidebar-first">
            <?php print $left; ?>
          </div></div> <!-- /#sidebar-first-inner, /#sidebar-first -->
        <?php endif; ?>

        <?php if ($right): ?>
          <div id="sidebar-second"><div id="sidebar-second-inner" class="region region-sidebar-second">
            <?php print $right; ?>
          </div></div> <!-- /#sidebar-second-inner, /#sidebar-second -->
        <?php endif; ?>

      </div></div> <!-- /#main-inner, /#main -->

      <?php if ($footer || $footer_message): ?>
        <div id="footer"><div id="footer-inner" class="region region-footer">

          <?php if ($footer_message): ?>
            <div id="footer-message"><?php print $footer_message; ?></div>
          <?php endif; ?>

          <?php print $footer; ?>

        </div></div> <!-- /#footer-inner, /#footer -->
      <?php endif; ?>

    </div></div> <!-- /#page-inner, /#page -->
  </div> <!-- /#body-wrapper -->

  <?php if ($closure_region): ?>
    <div id="closure-blocks" class="region region-closure"><?php print $closure_region; ?></div>
  <?php endif; ?>

  <?php print $closure; ?>

</body>
</html>
